package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@(!`0````````````(`/@`!````H")```````!``````````,C'````
M`````````$``.``(`$``'``;``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````*S!````````K,$`````````
M`"````````$````&````L,$```````"PP6```````+#!8```````^`0`````
M``"0%0``````````(````````@````8```#8P0```````-C!8```````V,%@
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M````[+L```````#LNT```````.R[0```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```!(````$````%`````,```!'
M3E4`RR-"T_HJ,&X;]R8,=?>CVKFVMWL1````3P````0````(````(!`0``5`
M!(2J`@`!@(8!J$(H`"!/(`0+N*(X3;J$!@I/````40```%8```!;````7```
M`&,```!E````9P```&D```!L`````````&X```!P````<0```'(`````````
M`````'KP2FNA(@L@ZM/O#F[%WQ]&F`7&SMY'+6M_FGPNQ9NVU&34?'Q!CL4@
M_^0.N8WQ#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/+;TQW[H6Q@:@E#UH?Y
MG(%FK\QFQ;F<0,2)!9!#1=7L#!3BGLC5LG'G[U][,F+;[=O-XYX,.I<+I]VC
M:W^IG)OAIP(*H^#[20`````````````````````````````````````M`P``
M$@````````````````````````"L````$@````````````````````````"<
M`0``$@````````````````````````#$`P``$@``````````````````````
M``#?`P``$@````````````````````````!!`P``$@``````````````````
M``````!U`@``$@````````````````````````"H`P``$@``````````````
M```````````,````(``````````````````````````;````(```````````
M``````````````"(`0``$@`````````````````````````H!```$@``````
M``````````````````!C`P``$@````````````````````````!I`0``$@``
M``````````````````````![`0``$@````````````````````````!1`P``
M$@`````````````````````````/`P``$@````````````````````````!H
M`P``$@````````````````````````",`@``$@``````````````````````
M``!J!```$@`````````````````````````G`@``$@``````````````````
M``````#X````$@`````````````````````````7`@``$@``````````````
M``````````"3`P``$@````````````````````````#2`P``$@``````````
M``````````````#%`0``$@`````````````````````````O!```$@``````
M``````````````````"O`P``$@`````````````````````````Z!0``$@``
M``````````````````````"3`@``$@````````````````````````#E`0``
M$@````````````````````````!P`P``$@`````````````````````````P
M`@``$@````````````````````````"A`0``$@``````````````````````
M``"]`P``$@````````````````````````#X`P``$@``````````````````
M```````J`0``$@`````````````````````````O````$@``````````````
M```````````*!```$@````````````````````````!8`0``$@``````````
M``````````````##````$@`````````````````````````(`P``$@``````
M``````````````````#+`P``$@`````````````````````````\`0``$@``
M```````````````````````?!```$@````````````````````````!7`@``
M$@````````````````````````#8`P``$@````````````````````````!4
M!```$@````````````````````````#M`P``$@``````````````````````
M``!)`@``$@`````````````````````````4`P``$@``````````````````
M``````"F`0``$@````````````````````````""`P``$@``````````````
M``````````!C!```$@````````````````````````"V`P``$@``````````
M``````````````#G````$@`````````````````````````]````$@``````
M```````````````````8!```$@````````````````````````#2````$@``
M``````````````````````#Y`0``$@``````````````````````````!```
M$@````````````````````````"``@``$@`````````````````````````E
M`P``$@````````````````````````!+`0``$@``````````````````````
M``!Y`P``$@````````````````````````!&!```$@``````````````````
M```````8`0``$@````````````````````````!<!```$@``````````````
M``````````"@`P``$@`````````````````````````^`@``$@``````````
M``````````````!/````$@````````````````````````#3`0``$@``````
M``````````````````!>````$@````````````````````````"*````$@``
M```````````````````````\!```$@````````````````````````":`P``
M$@````````````````````````!S````$@`````````````````````````&
M`0``$@````````````````````````!E`@``$@````@@0```````````````
M``"S!0``$0`8`*#&8```````"`````````#<!```$@`.``A=0```````````
M``````!#!0``$@`-`,!(0```````?P````````"#!0``$0`8`)C&8```````
M"`````````#'!0``$@`-`'!-0```````%PH```````!W!```$@`-`$!)0```
M````*P(```````"T!```$@`-`#!"0```````!0````````#B!```$@`-`)!7
M0```````]P,```````"7!0``$@`-`/`\0```````0`````````#F!0``$@`-
M`'!+0```````_@$```````!M!0``$@`+`(`=0`````````````````"-!```
M$`#Q_ZC&8`````````````````#%!```$@`-`)`C0```````-`````````#X
M!```$@`-`%`[0```````3`````````!/!0``$0`/`"!=0```````!```````
M``!K!0``$@`-`)!;0```````+0````````"9!```$`#Q_T#78```````````
M``````">`@``$0`9`-#&8```````$P````````#4!0``$@`-`'!$0```````
M-@$```````!>!0``$``8`)#&8`````````````````";````$@```!@@0```
M```````````````<!0``$@`-`+!'0```````"@$```````!\!```$0`9`,#&
M8```````"`````````!]!```(0`9`,#&8```````"`````````"&!```$`#Q
M_ZC&8`````````````````#2!```$@`-`#!<0````````@````````"R`0``
M$@```"@>0`````````````````"(!0``$0`/``!@0```````ZEL```````!D
M!0``$@`-`*`B0`````````````````!S!0``$@`-`$!<0```````B0``````
M``!@!0``(``8`)#&8`````````````````!^!```(0`9`,#&8```````"```
M```````H!0``$@`-`(!'0```````(@`````````&!0``$@`-`$!!0```````
MX0````````#S!0``$@`-`+!%0```````RP$`````````;&EB<&5R;"YS;P!?
M7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E
M<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI
M=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP
M8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T
M<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP
M87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S=E]S971P
M=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A
M;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R
M;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V`'!E
M<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB
M<F5S;VQV+G-O+C(`;&EB;G-L+G-O+C$`;&EB9&PN<V\N,@!L:6)M+G-O+C8`
M;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB<'1H<F5A9"YS;RXP`&]P
M96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E
M='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E
M>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED`'-T<G1O:P!S
M=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`7U]S=')N8W!Y7V-H
M:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`
M9V5T=6ED`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<F5A9&1I<C8T
M`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S
M=&%R=%]M86EN`%]?96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O
M=7-R+VQI8C8T+W!E<FPU+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/5`!P
M87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M
M90!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?
M<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN
M:70`;F%M95]L;V%D7VUY7W!A<E]P;`!84U]);G1E<FYA;'-?4$%27T-,14%2
M4U1!0TL`<VEZ95]L;V%D7VUY7W!A<E]P;`!P87)?;6MT;7!D:7(`<&%R7W-E
M='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R
M+C0`1TQ)0D-?,BXS`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#7S(N
M,BXU`````@```````P`$``(````#``````````,``P``````!0`"``,``P`#
M``````````,``P````0``P`#```````#`````P`#``,```````8```````(`
M`P````,````#``,``P````(````'``,``P```````P```````P````(````#
M``0````#``,```````````````,``P`````````!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$````!``$````!``,``P`!``$````!``$``0`!
M``,``0`!``$````!``4`1P,``!````!@````%&EI#0``!P``!@``$````!-I
M:0T```8`"@8``!````!R&6D)```%`!0&```0````=!EI"0``!``@!@``$```
M`'4::0D```,`+`8````````!``$`^`(``!``````````=1II"0```@`L!@``
M`````/C#8```````!@````D``````````````,#&8```````!0```&8`````
M`````````-#&8```````!0```&$``````````````!C$8```````!P````$`
M`````````````"#$8```````!P````(``````````````"C$8```````!P``
M``,``````````````##$8```````!P````0``````````````#C$8```````
M!P````4``````````````$#$8```````!P````8``````````````$C$8```
M````!P````<``````````````%#$8```````!P````@``````````````%C$
M8```````!P```&H``````````````&#$8```````!P````L`````````````
M`&C$8```````!P````P``````````````'#$8```````!P````T`````````
M`````'C$8```````!P````X``````````````(#$8```````!P````\`````
M`````````(C$8```````!P```!```````````````)#$8```````!P```!$`
M`````````````)C$8```````!P```!(``````````````*#$8```````!P``
M`!,``````````````*C$8```````!P```!0``````````````+#$8```````
M!P```!4``````````````+C$8```````!P```!8``````````````,#$8```
M````!P```!<``````````````,C$8```````!P```!@``````````````-#$
M8```````!P```!D``````````````-C$8```````!P```!H`````````````
M`.#$8```````!P```!L``````````````.C$8```````!P```!P`````````
M`````/#$8```````!P```!T``````````````/C$8```````!P```!X`````
M``````````#%8```````!P```!\```````````````C%8```````!P```"``
M`````````````!#%8```````!P```"$``````````````!C%8```````!P``
M`"(``````````````"#%8```````!P```",``````````````"C%8```````
M!P```"0``````````````##%8```````!P```"4``````````````#C%8```
M````!P```"8``````````````$#%8```````!P```"<``````````````$C%
M8```````!P```$\``````````````%#%8```````!P```&0`````````````
M`%C%8```````!P```"@``````````````&#%8```````!P```"D`````````
M`````&C%8```````!P```"H``````````````'#%8```````!P```"L`````
M`````````'C%8```````!P```"P``````````````(#%8```````!P```"T`
M`````````````(C%8```````!P```"X``````````````)#%8```````!P``
M`"\``````````````)C%8```````!P```#```````````````*#%8```````
M!P```#$``````````````*C%8```````!P```#(``````````````+#%8```
M````!P```#,``````````````+C%8```````!P```#0``````````````,#%
M8```````!P```#4``````````````,C%8```````!P```#8`````````````
M`-#%8```````!P```#<``````````````-C%8```````!P```#@`````````
M`````.#%8```````!P```#D``````````````.C%8```````!P```#H`````
M`````````/#%8```````!P```#L``````````````/C%8```````!P```#P`
M``````````````#&8```````!P```#T```````````````C&8```````!P``
M`#X``````````````!#&8```````!P```#\``````````````!C&8```````
M!P```$```````````````"#&8```````!P```$$``````````````"C&8```
M````!P```$(``````````````##&8```````!P```$,``````````````#C&
M8```````!P```$0``````````````$#&8```````!P```$4`````````````
M`$C&8```````!P```$8``````````````%#&8```````!P```$<`````````
M`````%C&8```````!P```$@``````````````&#&8```````!P```$D`````
M`````````&C&8```````!P```$H``````````````'#&8```````!P```$L`
M`````````````'C&8```````!P```$P``````````````(#&8```````!P``
M`$T``````````````(C&8```````!P```$X``````````````$B#[`CH0P4`
M`.C2!0``Z#T_``!(@\0(P_\U:J8@`/\E;*8@``\?0`#_)6JF(`!H`````.G@
M_____R5BIB``:`$```#IT/____\E6J8@`&@"````Z<#_____)5*F(`!H`P``
M`.FP_____R5*IB``:`0```#IH/____\E0J8@`&@%````Z9#_____)3JF(`!H
M!@```.F`_____R4RIB``:`<```#I</____\E*J8@`&@(````Z6#_____)2*F
M(`!H"0```.E0_____R4:IB``:`H```#I0/____\E$J8@`&@+````Z3#_____
M)0JF(`!H#````.D@_____R4"IB``:`T```#I$/____\E^J4@`&@.````Z0#_
M____)?*E(`!H#P```.GP_O___R7JI2``:!````#IX/[___\EXJ4@`&@1````
MZ=#^____)=JE(`!H$@```.G`_O___R72I2``:!,```#IL/[___\ERJ4@`&@4
M````Z:#^____)<*E(`!H%0```.F0_O___R6ZI2``:!8```#I@/[___\ELJ4@
M`&@7````Z7#^____):JE(`!H&````.E@_O___R6BI2``:!D```#I4/[___\E
MFJ4@`&@:````Z4#^____)9*E(`!H&P```.DP_O___R6*I2``:!P```#I(/[_
M__\E@J4@`&@=````Z1#^____)7JE(`!H'@```.D`_O___R5RI2``:!\```#I
M\/W___\E:J4@`&@@````Z>#]____)6*E(`!H(0```.G0_?___R5:I2``:"(`
M``#IP/W___\E4J4@`&@C````Z;#]____)4JE(`!H)````.F@_?___R5"I2``
M:"4```#ID/W___\E.J4@`&@F````Z8#]____)3*E(`!H)P```.EP_?___R4J
MI2``:"@```#I8/W___\E(J4@`&@I````Z5#]____)1JE(`!H*@```.E`_?__
M_R42I2``:"L```#I,/W___\E"J4@`&@L````Z2#]____)0*E(`!H+0```.D0
M_?___R7ZI"``:"X```#I`/W___\E\J0@`&@O````Z?#\____)>JD(`!H,```
M`.G@_/___R7BI"``:#$```#IT/S___\EVJ0@`&@R````Z<#\____)=*D(`!H
M,P```.FP_/___R7*I"``:#0```#IH/S___\EPJ0@`&@U````Z9#\____);JD
M(`!H-@```.F`_/___R6RI"``:#<```#I</S___\EJJ0@`&@X````Z6#\____
M):*D(`!H.0```.E0_/___R6:I"``:#H```#I0/S___\EDJ0@`&@[````Z3#\
M____)8JD(`!H/````.D@_/___R6"I"``:#T```#I$/S___\E>J0@`&@^````
MZ0#\____)7*D(`!H/P```.GP^____R5JI"``:$````#IX/O___\E8J0@`&A!
M````Z=#[____)5JD(`!H0@```.G`^____R52I"``:$,```#IL/O___\E2J0@
M`&A$````Z:#[____)4*D(`!H10```.F0^____R4ZI"``:$8```#I@/O___\E
M,J0@`&A'````Z7#[____)2JD(`!H2````.E@^____R4BI"``:$D```#I4/O_
M__\E&J0@`&A*````Z4#[____)1*D(`!H2P```.DP^____R4*I"``:$P```#I
M(/O___\E`J0@`&A-````Z1#[____)?JC(`!H3@```.D`^___```````````Q
M[4F)T5Y(B>)(@^3P4%1)Q\`P7$``2,?!0%Q``$C'QT!)0`#H__O___20D$B#
M[`A(BP4AH2``2(7`=`+_T$B#Q`C#D)"0D)"0D)"0D)"0D%5(B>532(/L"(`]
MZ*,@``!U2[O(P6``2(L%XJ,@`$B!Z\#!8`!(P?L#2(/K`4@YV',D9@\?1```
M2(/``4B)!;VC(`#_%,7`P6``2(L%KZ,@`$@YV'+BQ@6;HR```4B#Q`A;R<-F
M9F8N#Q^$``````!(@SUHGB```%5(B>5T$K@`````2(7`=`B_T,%@`,G_X,G#
MD)"0D)"0D)"0D)"0D)`/M@](B?B$R70H2(L%ISL``$B-5P$/MC!(B?@/'T0`
M`$`X\0^V"D@/1,)(@\(!A,EU[O/#9F9F+@\?A```````54R-3S@QR5-(@>P0
M`@``2(UT)(@/'T``28L4"4B)T$F)T$C!X`A)P>`808/@_R4``/\`3`G`28G0
M2<'H"$&!X`#_``!,"<!)B=!)P>@808'@_P```$P)P$F)T$G!Z"!(B01.3(G`
M2<'@&$C!X`A!@^#_)0``_P!,"<!)B=!(P>HX2<'H*$&!X`#_``!,"<!("=!(
MB41."$B#P0A(@_E`#X5S____2(U6:$B!QF@"``!(BT+82#,"2#-"J$@S0IA(
MB<%(`<!(P>D?2`G!@^'_2(E*&$B#P@A(.?)UU$R+!TB+3R!(`TPDB$B+5PA(
MBU\02(MW&$R)P$R)Q4C!Y05(P>@;2`GH@^#_3(V4`9EY@EI(B=!(B=E(]]!(
M(=%((?!(`W0DD$@)R$R)P4$!PDB)T$C!XAY(P>@"2/?12`G02"'92`-<))B#
MX/](B<),(<)("<I,B=%,C8P6F7F"6DR)TDC!X05(P>H;3(G62`G*3(G!1HT,
M"DR)PDC!Z0)(P>(>2`G13(G23(G-@^'_2/?22"'.2"'"2`GR2(VT$YEY@EI,
MB<I,B<M(P>,%2,'J&T@)VDR)RXTT,DR)TDG!XAY(P>H"2/?33`G22`-$)*!(
M(<N#XO](`TPDJ$@AU4@)ZTB)]4R-E!B9>8):2(GP2(GS2,'C!4C!Z!M("=A(
MB?-&C1003(G(2<'A'DC!Z`)(]]-,"<A((=-(`U0DL(/@_T@AQ4@)ZTR-C!F9
M>8):3(G13(G32,'C!4C!Z1M("=E,B=-&C0P)2(GQ2,'F'DC!Z0)(]]-("?%,
MB=9((<.#X?],B<U((<Y("?-(C;0:F7F"6DR)RDR)RTC!XP5(P>H;2`G:3(G+
MC30R3(G22<'B'DC!Z@)(]]-,"=)(`T0DN$@ARX/B_T@#3"3`2"'52`GK2(GU
M3(V4&)EY@EI(B?!(B?-(P>,%2,'H&T@)V$B)\T:-%!!,B<A)P>$>2,'H`DCW
MTTP)R$@ATT@#5"3(@^#_2"'%2`GK3(V,&9EY@EI,B=%,B=-(P>,%2,'I&T@)
MV4R)TT:-#`E(B?%(P>8>2,'I`DCWTT@)\4R)UD@APX/A_TR)S4@ASD@)\TB-
MM!J9>8):3(G*3(G+2,'C!4C!ZAM("=I,B<N--#),B=))P>(>2,'J`DCWTTP)
MTD@#1"302"'+@^+_2`-,)-A((=5(">M(B?5,C908F7F"6DB)\$B)\TC!XP5(
MP>@;2`G82(GS1HT4$$R)R$G!X1Y(P>@"2/?33`G(2"'32`-4)."#X/]((<5(
M">M,C8P9F7F"6DR)T4R)TTC!XP5(P>D;2`G93(G31HT,"4B)\4C!YAY(P>D"
M2/?32`GQ3(G62"'#@^'_3(G-2"'.2`GS2(VT&IEY@EI,B<I,B<M(P>,%2,'J
M&T@)VDR)RXTT,DR)TDG!XAY(P>H"2/?33`G22`-$).A((<N#XO](`TPD\$@A
MU4@)ZTB)]4R-E!B9>8):2(GP2(GS2,'C!4C!Z!M("=A(B?-&C1003(G(2<'A
M'DC!Z`)(]]-,"<A((=-(`U0D^(/@_T@AQ4@)ZTR-C!F9>8):3(G13(G32,'C
M!4C!Z1M("=E,B=-&C0P)2(GQ2,'F'DC!Z0)(]]-("?%,B=9((<.#X?],B<U(
M(<Y("?-(C;0:F7F"6DR)RDR)RTC!XP5(P>H;2`G:3(G+C30R3(G22<'B'DC!
MZ@)(]]-,"=)(`P0D2"'+@^+_2`-,)`A((=5(">M(B?5,C908F7F"6DB)\$B)
M\TC!XP5(P>@;2`G82(GS1HT4$$R)R$G!X1Y(P>@"2/?33`G(2"'32`-4)!"#
MX/]((<5(">M,C8P9F7F"6DR)T4R)TTC!XP5(P>D;2`G93(G31HT,"4B)\4C!
MYAY(P>D"2/?32`GQ3(G62"'#@^'_3(G-2"'.2`GS2(VT&IEY@EI,B<I,B<M(
MP>,%2,'J&T@)VDR)RXTT,DR)TDG!XAY(P>H"2/?33`G22`-$)!A((<N#XO](
M`TPD($@AU4@)ZTB-K!B9>8):2(GP2(GS2,'C!4C!Z!M("=B)ZXTL&$R)R$G!
MX1Y(P>@"2(GS3`G(2/?328GQ@^#_2"'32`-4)"A)(<%,"<M,C8P9F7F"6DB)
MZ4B)ZTC!XP5(P>D;2`G91HT,"4B)\4C!YAY(P>D"2`GQ3(G.@^'_2,'F!4B)
MRT@QPT@QZTB-G!JAZ]EN3(G*2,'J&T@)\HT<&DB)ZDC!Y1Y(P>H"2`GJ@^+_
M2`-$)#!(B=9(,<Y(`TPD.$PQSDB-K#"AZ]EN2(G82(G>2,'F!4C!Z!M("?")
M[HTL,$R)R$G!X1Y(P>@"3`G(28GI@^#_2<'A!4B)QD@QUD@#5"1`2#'>2(VT
M,:'KV6Y(B>E(P>D;3`G)C30Q2(G92,'C'DC!Z0)("=E)B?&#X?])P>$%2(G+
M2#'#2`-$)$A(,>M(C9P:H>O9;DB)\DC!ZAM,"<J-'!I(B>I(P>4>2,'J`D@)
MZDF)V8/B_TB)U4@QS4@Q]4G!X05(`TPD4$B-K"BAZ]EN2(G82,'H&TP)R$&)
MZ4*-+`A(B?!(P>8>2,'H`D@)\$F)Z8/@_TG!X05(B<9(,=9(`U0D6$@QWDB-
MM#&AZ]EN2(GI2,'I&TP)R8TT,4B)V4C!XQY(P>D"2`G928GQ@^'_2<'A!4B)
MRT@QPT@#1"1@2#'K2(V<&J'KV6Y(B?)(P>H;3`G*C1P:2(GJ2,'E'DC!Z@)(
M">I)B=F#XO])P>$%2(G52#'-2#'U2(VL**'KV6Y(B=A(P>@;3`G(08GJ2`-,
M)&A"C2P02(GP2,'F'DC!Z`)("?!)B>F#X/])P>$%2(G&2#'62`-4)'!(,=Y(
MC;0QH>O9;DB)Z4C!Z1M,"<F--#%(B=E(P>,>2,'I`D@)V4F)\8/A_TG!X05(
MB<M(,<-(`T0D>$@QZTB-G!JAZ]EN2(GR2,'J&TP)RHT<&DB)ZDC!Y1Y(P>H"
M2`GJ28G9@^+_2<'A!4B)U4@QS4@Q]4B-K"BAZ]EN2(G82,'H&TP)R$&)Z4*-
M+`A(B?!(P>8>2,'H`D@)\$@#C"2`````28GI@^#_2<'A!4B)QD@QUD@#E"2(
M````2#'>2(VT,:'KV6Y(B>E(P>D;3`G)C30Q2(G92,'C'DC!Z0)("=E)B?&#
MX?])P>$%2(G+2#'#2`.$))````!(,>M(C9P:H>O9;DB)\DC!ZAM,"<J-'!I(
MB>I(P>4>2,'J`D@)ZDF)V8/B_TG!X05(B=5(,<U(`XPDF````$@Q]4B-K"BA
MZ]EN2(G82,'H&TP)R$&)ZD*-+!!(B?!(P>8>2,'H`D@)\$F)Z8/@_TB)QD@Q
MUDG!X05(`Y0DH````$@QWDB-M#&AZ]EN2(GI2,'I&TP)R8TT,4B)V4C!XQY(
MP>D"2`G928GQ@^'_2<'A!4B)RT@QPT@#A"2H````2#'K2(V<&J'KV6Y(B?)(
MP>H;3`G*C1P:2(GJ2,'E'DC!Z@)(">J#XO](B=5(,<U(`XPDL````$@Q]4R-
MC"BAZ]EN2(G82(G=2,'E!4C!Z!M(">A&C0P(2(GP2,'F'DC!Z`)("?"#X/](
MB<9(,=9(,=Y(C:PQH>O9;DR)R4R)SDC!Z1M(P>8%2`.4)+@```!("?&)[HTL
M,4B)WDC!XQY(P>X"2`G>@^;_2(GQ2#'!2`.$),````!,,<E(C9P*H>O9;DB)
MZDB)Z4C!X05(P>H;2`G*3(G)2<'A'DC!Z0*-'!I,"<F#X?](B<I(,?)(,>I,
MC8P0H>O9;DB)V$B)VDC!X@5(P>@;2`G02(GJ2,'E'D:-#`A(P>H"N-R\&X](
M">I(B<5(`ZPDR````(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*2(TL
M+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<)-``
M``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;
M3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPDV````(/A_TF)RDDA\DF-%!%)
MB<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!
MZ@)(">I(B<5(`ZPDX````(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*
M2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<
M).@```"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(
MP>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD\````(/A_TF)RDDA\DF-
M%!%)B<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E
M'DC!Z@)(">I(B<5(`ZPD^````(/B_TF)TDB-=#4`2(G52`G-22'*2"'=3`G5
M38G*2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#
M2`.<)``!``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!
MX@5(P>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD"`$``(/A_TF)RDDA
M\DF-%!%)B<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ
M2,'E'DC!Z@)(">I(B<5(`ZPD$`$``(/B_TF)TDDARDB-=#4`2(G52`G-2"'=
M3`G538G*2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>
M2(G#2`.<)!@!``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)
MZ4G!X@5(P>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD(`$``(/A_TF)
MRDDA\DF-%!%)B<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*
M2(GJ2,'E'DC!Z@)(">I(B<5(`ZPD*`$``(/B_TF)TDDARDB-=#4`2(G52`G-
M2"'=3`G538G*2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"
M2`G>2(G#2`.<)#`!``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<
M&4B)Z4G!X@5(P>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD.`$``(/A
M_TF)RDDA\DF-%!%)B<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&
MC0P*2(GJ2,'E'DC!Z@)(">I(B<5(`ZPD0`$``(/B_TF)TDDARDB-=#4`2(G5
M2`G-2"'=3`G538G*2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(
MP>X"2`G>2(G#2`.<)$@!``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ
M2(T<&4B)Z4G!X@5(P>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD4`$`
M`(/A_TF)RDF-%!%)B<E)"?%)(?))(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,
M"=)&C0P*2(GJ2,'E'DC!Z@)(">I(B<5(`ZPD6`$``(/B_T@#A"1@`0``28G2
M22'*2(UT-0!(B=5("<U(C0P(2"'=3`G538G*2(TL+DR)SDG!X@5(P>X;3`G6
M08GJ0HTL%DB)WDC!XQY(P>X"38G*2`G>2<'J`H/F_TB)\$B)\T@)T$@ATTPA
MR$G!X1Y("=A(C1P!2(GH2(GI2,'A!4C!Z!M("<A-"<J-'!BXUL%BRD&#XO](
MB<%(`XPD:`$``$F)V4G!X05(C1013(G12#'Q2#'I2(T,"DB)VDC!ZAM,"<I)
MB>E(P>4>1(T<"DB)PD@#E"1P`0``2<'I`DD)Z4R)V4&#X?](P>$%2(TT,DR)
MRDPQTD@QVDB-+!9,B=I(P>H;2`G*B>F-+`I(B=E(P>,>2,'I`D@)V4B)PT@#
MG"1X`0``@^'_2(GN2(G*2,'F!4PQRDPQVDP!TT@!TTB)ZDC!ZAM("?)(B<:-
M'!I,B=I)P>,>2,'J`DP)VH/B_T@#M"2``0``3HT,#DB)UD@QSD@Q[DV-'#%(
MB=Y)B=E)P>$%2,'N&TP)SD:-'!Y(B>Y(P>4>2,'N`D@)[DB)Q4@#K"2(`0``
M@^;_38G92<'A!4B-3`T`2(GU2#'52#'=2(TL*4R)V4C!Z1M,"<E!B>E&C10)
M2(G92,'C'DC!Z0)("=E(B<-(`YPDD`$``(/A_TR)U4C!Y05(C1032(G+2#'S
M3#';2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#2`.<))@!``!)P>,>2,'J`DP)
MVH/B_TB--#-(B=-(,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM("?-,B=9)P>(>
M1HT<&TB)PT@#G"2@`0``2,'N`DP)UDR)W8/F_TC!Y05(C0P+2(GS2#'33#'+
M2(T<&4R)V4C!Z1M(">E$C1093(G)2(G#2`.<)*@!``!)P>$>2,'I`DP)R4R)
MU8/A_TC!Y05(C1032(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#
M2`.<)+`!``!)P>,>2,'J`DP)VH/B_TB--#-(B=-(,<M,,=-,C1P>3(G+3(G.
M2,'F!4C!ZQM("?-,B=9)P>(>1HT<&TB)PT@#G"2X`0``2,'N`DP)UDR)W8/F
M_TC!Y05(C0P+2(GS2#'33#'+2(T<&4R)V4C!Z1M(">E$C1093(G)2(G#2`.<
M),`!``!)P>$>2,'I`DP)R4R)U8/A_TC!Y05(C1032(G+2#'S3#';2(T<&DR)
MTDC!ZAM(">I$C0P:3(G:2(G#2`.<),@!``!)P>,>2,'J`DP)VH/B_TB--#-(
MB=-(,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM("?-,B=9)P>(>2,'N`D:-'!M(
MB<-,"=9(`YPDT`$``(/F_TR)W4C!Y05(C0P+2(GS2#'33#'+2(T<&4R)V4C!
MZ1M(">E$C1093(G)2(G#2`.<)-@!``!)P>$>2,'I`DP)R4R)U8/A_TC!Y05(
MC1032(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#2`.<).`!``!)
MP>,>2,'J`DP)VH/B_TB--#-(B=-(,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM(
M"?-,B=9)P>(>1HT<&TB)PT@#G"3H`0``2,'N`DP)UDR)W8/F_TB-#`M(B?-(
M,=-(P>4%3#'+2(T<&4R)V4C!Z1M(">E$C1093(G)2(G#2`.<)/`!``!)P>$>
M2,'I`DP)R4R)U8/A_TC!Y05(C1032(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$
MC0P:3(G:2(G#2`.<)/@!``!(P>H"2<'C'DP)VD@#A"0``@``@^+_2(TT,TB)
MTT@QRTB-#`A,,=-(C2P>3(G+3(G.2,'F!4C!ZQM("?.)[HTL,TR)UDG!XAY(
MP>X"3(G+3`G638G*2,'K`H/F_TG!XAY(B?!,"=-(,=!,,<A)B>E(`<%(B>A)
MP>$%2,'H&TP)R`'(1HT$`$R)!P-O"`-?$`-W&`-7($B);PA(B5\02(EW&$B)
M5R!(@<00`@``6UW##Q]$``!,B60DX$R)?"3X28G\2(E<)-!(B6PDV$F)]TR)
M;"3H3(ET)/!(@^PX2(7_=2LQP$B+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,
MBWPD,$B#Q#C#9@\?1```3(LU(8P@`$V%]G3)#[8'/#UT783`28G]=%9)@\4!
M00^V10`\/70$A,!U[T4IY4F+'DB%VW2?36/M3(GU#Q]``$R)ZDR)YDB)W^C"
MX___A<!U!T*`/"L]=!](@\4(2(M=`$B%VW7:Z6K___\/'T0``$4Q[>NY#Q\`
M3"GU2HU$*P%(P?T#08DOZ4O___]F9F8N#Q^$``````!(@^P8,<!(C70D#.@`
M____2(/$&,-F9BX/'X0``````$B#[`B+!3J+(`"#^/]T"4B#Q`C##Q]``#'`
MOS!=0`#HO/___TB%P'0?#[8`A,!T&#PP#Y7`#[;`B04&BR``2(/$",,/'T0`
M`#'`Z^P/'T``54B)_5-(@^P82(U<)`SK($AC1"0,2,'@`T@#!0"+(`!(@\`(
M2(L02(722(E0^'7P,<!(B=Y(B>_H8_[__TB%P'7.2(/$&%M=PP\?@`````!(
MB6PDZ$R);"3X2(GU2(E<).!,B60D\$B![#@0``!)B=5(B>:Z_P\``+\Z74``
M9$B+!"4H````2(F$)`@0```QP.A"Y/__A<`/CHH```"-4/],8^)"@#PD`'1U
M3&/@3(GBOB\```!(B>?HNN'__TB%P'1E,?_HON7__XLXZ#?A__],B>%(B>)(
MB>Y(B<?HYN/__TB+A"0($```9$@S!"4H````=5%(BYPD&!```$B+K"0@$```
M3(ND)"@0``!,BZPD,!```$B!Q#@0``###Q\`A=)UB@\?0``Q_^A9Y?__BSCH
MTN#__TR)ZDB)[DB)Q^A$XO__ZYSH#>3__P\?1```2(/L"#'_Z"WE__^+..BF
MX/__OO____](B<?HB>+__S'_Z!+E__^+..B+X/__,=*^,#U``$B)QTB#Q`CI
M2.7__U,Q_^CPY/__BSCH:>#__TB)Q^AQX/__2(L`,?](BU@(Z-/D__^+..A,
MX/__2(G'Z`3A__\/M@`Q_XA#(.BWY/__BSCH,.#__TB)Q^@XX/__2(L`,?](
MBU@(Z)KD__^+..@3X/__2(G'Z-O@__](BP`Q_P^W0"!F)?\!9HE#(NAUY/__
MBSCH[M___TB)Q^CVW___2(L`,?](BU@(Z%CD__^+..C1W___,=*^U%Y``$B)
MQ^C"X___,?](B4,HZ#?D__^+..BPW___2(G'Z+C?__](BP`Q_TB+6`CH&N3_
M_XLXZ)/?__](B<?H&^#__TB+`#'_2(E#,.C]X___BSCH=M___TB)Q^A^W___
M2(L`,?](BU@(Z.#C__^+..A9W___2(G'Z-'B__\QTDB#.`!T(#'_Z,+C__^+
M..@[W___2(G'Z+/B__](BP!(BY"H````2(E3.#'_Z)[C__^+..@7W___2(G'
MZ!_?__](BP`Q_TB+0`A(QT!``````.AYX___BSCH\M[__TB)Q^CZWO__2(L`
M,?](BT`(2,=`2`````#H5./__XLXZ,W>__](B<?HU=[__TB+`#'_2(M8".@W
MX___BSCHL-[__TB)Q^C8XO__2(L`2(E#4%O##Q^``````$%6055!5%5(B?U3
M2('LD````$B%_W0%@#\`=11(@<20````6UU!7$%=05[##Q]``.B#X/__2(7`
M2(G#=-\/'P!(B=_H`./__TB%P`^$MP```$R-<!,/MA7>'0``#[9`$SG0#X3(
M````#[85RAT``#G0#X39````2(GOZ"G@__],B?=)B<3H'N#__T&-?`0"2&/_
MZ!'?__]-B?%(B<=)B<1)B>BY3%U``$C'PO____^^`0```#'`Z/WA__](B>),
MB>:_`0```.B=X?__@_C_=!2+1"08)0#P```]`$````^$G````$R)Y^@,W___
M3(GGZ*3?__](B=_H3.+__TB%P`^%3/___P\?`$B)W^B8X?__2(GOZ/#>__](
M@<20````6UU!7$%=05[##Q^$``````!!#[96`3H5`!T```^$__[__^DB____
M9BX/'X0``````$$/MD8!.@7?'```#X46____00^V1@(Z!<\<```/A,[^___I
M`/___V8/'X0``````$R)Y^AX_O__Z5____\/'P!32(G[,?_H?>'__XLXZ/;<
M__](B<?H?N#__TB)WDB)PK\!````Z.[?__^%P'0*,<!;PV8/'T0``#'_Z$GA
M__^+..C"W/__2(G'Z$K@__^+0!@E`/```#T`0```="4Q_^@DX?__BSCHG=S_
M_TB)Q^@EX/__BT`8)0#P```]`*```'6L2(G?O@(```#HN>#__X7`#Y3`#[;`
M6\,/'X``````2(E<).A(B6PD\$R)9"3X2('L."```$B-G"00$```9$B+!"4H
M````2(F$)!@@```QP.C2W?__0;E%74``08G`N5)=0``QP+H!$```O@$```!(
MB=_H,.#__X7`>3PQVTB+E"08(```9$@S%"4H````2(G8=6A(BYPD("```$B+
MK"0H(```3(ND)#`@``!(@<0X(```PP\?0`"Z`!```$B)YDB)W^B0WO__A<!!
MB<1XK4&-?"0!2&/_Z+S<__](A<!(B<-TFDUCY$B)YDB)QTR)XNB#WO__0L8$
M(P#K@NC7WO__9F9F9F9F+@\?A```````Z0O___]F9BX/'X0``````$B)7"30
M2(EL)-@QP$R)9"3@3(EL).A(B?-,B70D\$R)?"3X2(/L2(`^/4F)_`^4P$@!
MPTB)W^@]W?__2(UT)`Q!B<5,B><QP.BS]___2(7`2(G%=%M(B<?H&]W__T2)
MZD@YT`^"K0$```\?@``````/M@-(@\,!B$4`2(/%`83`=>XQP$B+7"082(ML
M)"!,BV0D*$R+;"0P3(MT)#A,BWPD0$B#Q$C#9@\?A```````2(L]R8,@`#'M
MOA````!(@S\`2(GX="!F#Q^$``````!(@\`(@\4!2(,X`'7SC74"2&/V2,'F
M`XL%TX,@`(7`="?HPM[__TB%P$F)QDB)!7V#(`!,8_UU2[C_____Z7+___]F
M#Q]$``!(B??'!9N#(``!````Z$[;__](A<!)B<9TUDQC_4B+-42#(`!(B<=*
MC13]`````.@<W?__3(DU+8,@`$O'1/X(`````(EL)`Q!#[84)(#Z/0^$L0``
M`(323(G@=0_II0```&8/'T0``(32=`Q(@\`!#[80@/H]=?")[44IY4C!Y0-(
M`RW@@B``08U\!0+HSMK__TB%P$B)10`/A%'___^+5"0,2(L%OH(@`$B+%-!!
M#[8$)(3`B`)T)CP]="))@\0!ZPD/'T0``#P]=!-!#[8$)$B#P@%)@\0!A,"(
M`G7IQ@(]2(/"`6:0#[8#2(/#`8@"2(/"`83`=>_I;/[__XML)`SI0?___TR)
MX.EI____9@\?A```````05=!5D%528G]051!O&A=0`!54[M>74``2(/L6$R+
M/;T:``!(QT0D(&A=0`!(QT0D*%Y=0`!(C6PD,$C'1"0P:UU``$C'1"0X85U`
M`$C'1"1`9EU``$C'1"1(U%Y``.LH3(GN2(G'2(E$)!#H>-O__TB%P'1+@#L`
M=#1(BT4`28G<2(/%"$B)PS'`3(GGZ"[V__](A<!T!8`X`'7$,<!,B>Y,B>?H
M)_W__X`[`'7,2(/$6%M=05Q!74%>05_##Q\`3(GOZ(#:__],B?](B40D&.AS
MVO__2(M4)!!)B<9(B=?H8]K__TB+3"082HU\,0%(`<?H4=G__TB+5"0028G&
M2(G'38GY38GHN8->0`"^`0```#'`2(D4)$C'PO_____H--S__TR)]DR)YS'`
MZ)_\___I/____V8N#Q^$``````!(@^PXOWA=0`!D2(L$)2@```!(B40D*#'`
M2(L%4!D``$B)!"1(BP5-&0``2(E$)`A(BP5)&0``2(E$)!!(BP5%&0``2(E$
M)!@/MP5!&0``9HE$)"`QP.B5]?__,<"_@5U``.B)]?__,<"_B5U``.A]]?__
M,<"_DEU``.AQ]?__,<"_F5U``.AE]?__,<"_J5U``.A9]?__,<"_M5U``.A-
M]?__,<"_,%U``.A!]?__,<"_OEU``.@U]?__,<"_R%U``.@I]?__,<"_TEU`
M`.@=]?__,<"_WUU``.@1]?__,<"_Z%U``.@%]?__,<"_\UU``.B)]/__2(7`
M=`](B<:_OEU``#'`Z(7[__\QP+\$7D``Z&GT__](A<!T#TB)QK\67D``,<#H
M9?O__S'`OR%>0`#H2?3__TB%P'0\2(G&O[5=0``QP.A%^___,<"^35Y``+^9
M74``Z#3[__](BT0D*&1(,P0E*````'5:2(/$.,,/'X``````,<"_,5Y``.C\
M\___2(7`=!=(B<:_,%U``#'`Z/CZ___KL68/'T0``$B-="01OT)>0`"Y"@``
M`/.F=9A(C70D&[\P74``,<#HS/K__^N%Z'W9__\/'T0``$B#[`CHO]G__XG'
MZ,C7__](B<(QP$B%TG0#2(L"2(/$",-F9F9F9BX/'X0``````$B%_U-(B?MT
M5X`_`'12Z/77__](C50#_T@YTP^#W0```$B+/7`7```/M@H/M@<XP70*ZU`/
M'T``.`IU2$B#Z@%(.=-R\T@YVG5.#[8".@</A(L```!;Z7W7__\/'T0``+\"
M````Z)[6__](A<!T!6;'`"X`6\-F+@\?A```````.`)TP4B#Z@%(.=-R\T@Y
MVG2X9@\?1```2(/J`4@YTW,'#[8".@=T\$@IVC'`2(U*`DB!^0`0``!WNDB)
MWDB#P@&Y`!```+\@QV``Z&C5__^X(,=@`%O#9@\?A```````OP(```#H'M;_
M_TB)PC'`2(72=(!FQP(N`$B)T%O#2(L]DQ8``.D[____9@\?1```54B)_5-(
M@^P(Z.+^__\/M@A(B<.$R70J2(L5:18```^V,DB-4`%F+@\?A```````0#CQ
M#[8*2`]$VDB#P@&$R77N,<#H1_+__X7`=!U(A>UT&(!]``!T$KY/7D``2(G?
MZ#/7__](.=AT!TB#Q`A;7<-(@\0(2(GO6UWIT?7__Y!32(/L((E\)!Q(B70D
M$$B-?"0<2(E4)`A(C70D$$B-5"0(Z+'8__^Z*!Y``+\8($``2(G6Z)<2```Q
M_^CXU?__@#@`=3;HWM7__TB%P$B)!8R-(``/A+8!``!(B<?HEM;__S'_Z'_8
M__^+..CXT___2(G'Z+#7___&```Q_^AFV/__BSCHW]/__TB)Q^AGV/__@`@"
M,?_H3=C__XLXZ,;3__](B<?H3MC__X`(`8M\)!R#QP5(8_](A?\/B!@!``#R
M2`\JQ_(/6`7+%0``9@\N!<L5```/AS\!``!(P><#Z&37__](BW0D$$B)!0B-
M(`!(BQ9(QT`(5%Y``$C'0!``8$``2,=`&%=>0`!(B1"+?"0<QP74C"``!```
M`(/_`7XCN@@```"Y`0````\?1```2(L<%H/!`4B)7!`82(/""#G/?^R-5P1%
M,<!(B<&^P%M``$ACTDC'1-#X`````(U7`TB+/7B,(`#H6]/__X7`B<-T/4B+
M/6:,(`#H"=;__S'`OZE=0`#H9?#__TB%P'0P2(L]28P@`.CLTO__Z`?5__^)
MV$B#Q"!;PP\?@`````!(BSTIC"``Z-S3__^)P^NS2(L](8P@`$B%_W0IZ*_]
M___KO0\?1```2(GX2(GZ2-'H@^(!2`G0\D@/*L#R#UC`Z=#^__^_M5U``.CQ
M[___2(7`2(G'2(D%W(L@`'2"Z[R_`0```.C^TO__OM#&8`"_6UU``#'`Z.W5
M__\/'T0``$%7059!54F)]4%428G\O[5=0`!54TB![#@0``!D2(L$)2@```!(
MB80D*!```#'`Z(SO__](BQV=$P``3(GG2(G%2(G>Z)_4__](A<!T.TR)YK_2
M74``,<#H<_;__TB+E"0H$```9$@S%"4H````3(G@#X6"`0``2('$.!```%M=
M05Q!74%>05_#3(GGZ+?3__],BSU($P``3(GOB40D'$R)_N@!U?__2(7`28G`
M=)^+5"0<3(UL)"!!ODI=0`"#P@&)5"0<#Q\`08`X`$T/1,9(A>UT'4R)QDB)
M[TR)1"00Z+/4__^%P$R+1"00#X2^````3(G'3(E$)!#H2=/__TR+1"002&/0
M00^V3!#_.@MU(4F-5!#_9BX/'X0```````^V2O_&`@"#Z`%(@^H!.@MT[@-$
M)!P]_P\```^/#?___TF)V;F#7D``N@`0``"^`0```$R)[S'`3(DD).CWU/__
M,?_H4-7__XLXZ,G0__](B<?H4=3__TR)[DB)PK\!````Z('4__^%P'4E,?_H
M)M7__XLXZ)_0__](B<?H)]3__XM`&"4`\```/0"```!T&S'_3(G^Z.[3__](
MA<!)B<`/A0+____I@_[__[X!````3(GOZ*#4__^%P'743(GNO])=0`#HY_3_
M_TR)[^@GTO__28G$Z63^___HBM/__V:005=!5D%505154TB)^[^U74``2('L
MF($``&1(BP0E*````$B)A"2(@0``,<!(QX0D@````%I>0`!(QX0DB````&)>
M0`!(QX0DD````$I=0`!(QX0DF````-1>0`!(QT0D4!9>0`!(QT0D6`]>0`!(
MQT0D8&=>0`!(QT0D:%U>0`!(QT0D<&]>0`!(QT0D>-1>0`!(QX0DH````'->
M0`!(QX0DJ````'A>0`!(QX0DL````-1>0`#H!>W__TB%P'0)@#@`#X6G!0``
M,<#H0/G__TB%P$F)QP^$Q`4``$$/MB]`A.UT)^B>T?__3(GZ#Q\`2(L(2`^^
M[?8$:0AU`\8"7TB#P@$/MBI`A.UUY$B-;"18OQ9>0`#K&0\?A```````2(M]
M`$B#Q0B`/P`/A*\$```QP.B([/__2(7`28G$=.!(B<?HZ/'__X7`=-1,B>?H
MQ-#__TB%P$F)QG3$3(GWZ.30__],B?](B<7HV=#__XGJ1(VD`@0$``!-8^1,
MB>?HQ,___TR)YTB)Q4B)1"0XZ+3/__],BRT]$```38GPN8%>0`!(Q\+_____
M2(G'28G$O@$````QP$R)?"0(38GI2,<$)$]>0`#HC-+__[[M`0``3(GGZ!_3
M__\QP+]A74``Z-OK__](A<`/A*H$``!(B<?H(M#__TB+.TB)QNC_^___2(7`
M28G&#X2+!```3(GWZ#/0__^#^`-^-DACT+^*7D``N04```!)C706_/.F=2"#
M^`0/A/<#``"#Z`1(F$$/MD0&_T$Z10`/A.(#``!FD$R)\S'`Z(;K__^%P`^$
M]@```+Y-7D``OS!=0``QP.A=\O__Z&#/__]-B>F)!"1-B>"YJ%Y``$C'PO__
M__^^`0```$B)[S'`2,=$)`C47D``,=OHL='__^M*#Q^``````.BST/__@S@1
M=4OH&<___X/#`8D$)$V)Z4V)X+FV7D``2,?"_____[X!````2(GO,<!(QT0D
M$-1>0`")7"0(Z&71__^^[0$``$B)[^CXT?__@_C_=*M,B>?H*\___[^U74``
M2(GN,<#HM/'__TB)[^C<\___2(N4)(B!``!D2#,4)2@```!(BT0D.`^%T@8`
M`$B!Q)B!``!;74%<05U!7D%?PV8/'T0``#'V2(G?Z';/__^%P(E$)#0/A/3^
M__^Z`@```$C'QN[___^)Q^BGT/__3(V\),````"+?"0TN@8```!,B?[HCLW_
M_X"\),``````=0Z`O"3!````0P^$\`4``(M\)#1,C;0DP(```#'2,?:[B:O-
M[^A<T/__28U&.+G^W+J8NO#ATL-(QX0DP(````$C16=(B9PDR(```$B)C"30
M@```2,>$)-B```!V5#(02(F4)."```!(QX0DZ(````````!(QX0D\(``````
M``#'A"0X@0```````$B)1"1`9@\?1```BWPD-+H`@```3(G^Z-_,__^%P(G#
M#XZ=`@``2(NT).B```!(8]-(BX0D\(```(N\)#B!``"-#-9(.?%(B8PDZ(``
M`$R)_DB#T`!(P>H=2(F$)/"```!(`90D\(```(7_=&:Y0````"GY2&/_.<L/
M3LM(`WPD0$ACT8E,)"A(B50D2.AISO__BX0D.($``(M,)"@!R(/X0(F$)#B!
M```/A5S___](BW0D2$R)]RG+28TT-TB)="0HZ&S1__](BW0D*`\?@`````"#
M^S\/CK,````QP`\?1```2(L4!DR)]TB)E"3X@```2(M4!@A(B90D`($``$B+
M5`802(F4)`B!``!(BU0&&$B)E"00@0``2(M4!B!(B90D&($``$B+5`8H2(F4
M)""!``!(BU0&,$B)E"0H@0``2(M4!CA(B40D($B)="0H2(F4)#"!``#HU]#_
M_TB+1"0@B=I(BW0D*$B#P$`IPH/Z/P^/;/___X/K0(G:P>H&B=#!X@9(P>`&
M*=-(C70P0$B+?"1`2&/3N4@```#H^LO__XF<)#B!``#I7O[__V8/'T0``$R-
MI"2(````O5I>0`#K$Y!)BRPD28/$"(!]```/A%K[__](B>]%,?;H(^W__X7`
M=-](B>_H_\O__TB%P$F)QG3/Z3;[__]F+@\?A```````2(M;"$B%VP^$$_S_
M_TB)W^@#S/__2(/X`P^&`?S__TB-=`/\OX]>0`"Y!0```/.F#X3M^___Z>7[
M__\/'T0``$B)QTB)1"0@Z(/P__](BT0D($B)Q^B.R___2(E$)#CID/S__P\?
M0`!,BS/I;?O__TB-K"2H````OW->0``/'P`QP.@)Y___2(7`=!1(B<?H5,O_
M_TB%P$F)QP^%#/K__TB+?0!(@\4(@#\`==-!O\=>0`#I)/K__P\?A```````
MBWPD-.B/R?__2(N<).B```!,B[PD\(```$B)V$C!Z`.#X#](8]"#P`&#^#C&
MA!3X@```@`^/.0(``+HX````,?8IPDB828U\!CA(8]+H)LG__TR)^$R)]T2(
MO"0S@0``2,'H&(B<)#>!``!,C;0D<8$``(B$)#"!``!,B?A(P>@0B(0D,8$`
M`$R)^$C!Z`B(A"0R@0``2(G82,'H&(B$)#2!``!(B=A(P>@0B(0D-8$``$B)
MV$B-G"1`@0``2,'H"(B$)#:!``!)B=_HH,[__TB+A"3`@```28/'*$B)PHB$
M)'.!``!(P>H808G0B)0D<($``$B)PDC!ZA"(E"1Q@0``2(G"2(N$),B```!(
MP>H(B)0D<H$``$B)PHB$)'>!``!(P>H8B)0D=($``$B)PDC!ZA"(E"1U@0``
M2(G"2(N$)-"```!(P>H(B)0D=H$``$B)PHB$)'N!``!(P>H8B)0D>($``$B)
MPDC!ZA"(E"1Y@0``2(G"2(N$)-B```!(P>H(B)0D>H$``$B)PHB$)'^!``!(
MP>H8B)0D?($``$B)PDC!ZA"(E"1]@0``2(G"2(N$)."```!(P>H(B)0D?H$`
M`$B)PHB$)(.!``!(P>H8B)0D@($``$B)PDC!ZA"(E"2!@0``2(G"2,'J"(B4
M)(*!``#K$F8N#Q^$``````!%#[8&28/&`4B)WS'`10^VP+FC7D``2,?"____
M_[X!````2(/#`N@]R___3#G[==!(C80D0($``,:$)&B!````2,=$)`C47D``
M2(D$)$V)Z4V)X+F47D``2,?"_____[X!````2(GO,<#H^LK__^FB^?__38U&
M.+I`````,?8IPDB828T\`$ACTDR)1"0HZ.7&__],B??HU<S__TR+1"0HN0<`
M```QP$R)Q_-(J^F@_?__@+PDP@```$$/A0+Z__^`O"3#````0P^%]/G__X"\
M),0```!(#X7F^?__@+PDQ0```$4/A=CY__^+?"0TN@(```!(Q\;&____Z#G*
M__^+?"0TNBD```!,B?[H*,?__TC'1"0(U%Y``$R)/"3I*____^AQR?__9@\?
MA```````054Q_T%455-(@^P(Z(?*__^+..@`QO__2(G'Z"C(__^_F5U``,8`
M`3'`Z''C__](A<!T"8`X,0^$HP(``#'`Z-SM__\Q_^A-RO__BSCHQL7__[D+
M````N@$```"^SEY``$B)Q^C_QO__2(7`#X2W````2(M`$#';O0@```!,BV`H
MBP49?R``@_@!?SCIC0````\?@`````!)BW402(L%!7\@`$B+/"CHS,C__X7`
M=6B#PP&+!>=^(`!(@\4(C5,!.<)]6C'_Z,W)__^+..A&Q?__,<F)VDR)YDB)
MQ^@7R/__2(7`=#),BRA!]D4-!'6H,?_HH<G__XLXZ!K%__],B>ZY`@```#'2
M2(G'Z.C)__](B<;KAP\?`(L%@GX@`(U0_SG:#X1/`0``,?_H:,G__XLXZ.'$
M__^Y!0```+H!````OM->0`!(B<?H&L;__TB%P$B)PW0V2(M`$#'_2(LHZ#3)
M__^+..BMQ/__NM5>0`!(B<=(B>[H'<;__TB+0Q!(BQCV0PY`#X4T`0``,?_H
M!<G__XLXZ'[$__^Y!0```+H!````OO%=0`!(B<?HM\7__TB%P$B)PW0[,<"_
MTEU``.C;X?__2(7`28G$#X0G`0``2(M#$#'_2(LHZ+G(__^+..@RQ/__3(GB
M2(GN2(G'Z*3%__\Q_^B=R/__BSCH%L3__TB)Q^@^QO__,?_&``#HA,C__XLX
MZ/W#__](B<?HE<C__[^U74``2,<``````#'`Z&KA__](A<!(B058?2``#X3D
M````ONT!``!(B<?HA<C__X/X$70.A<!T"H/X_Y`/A2L!``!(@\0(6UU!7$%=
MPP\?@`````"#^`$/CJC^__^[`0```&8N#Q^$```````Q_X/#`>C^Q___BSCH
M=\/__TR)YDB)Q^BLQ/__.1WN?"``?]SI</[__P\?@``````Q_^C1Q___BSCH
M2L/__TB)WDB)Q^A_QO__Z:[^__]FD(!X`0`/A%K]__]F#Q]$``#I2/W__P\?
M`$B+!:E\(``Q_TR+($B+0Q!(BRCHB,?__XLXZ`'#__],B>)(B>Y(B<?H.^'_
M_^G*_O__2(L]=WP@`.BJ\O__2(D%6WP@`$B+0Q!(BRU@?"``3(L@0?9$)`T$
M='])BT0D$$B)[DB)Q^A5P___B<5(BT,02(L8]D,-!'0^2(M#$$B)PDB+!2A\
M(`")Z;]87T``2(LP,<#H-\;__XG!2(L%#GP@`$B+%?=[(`"_B%]``$B+,#'`
MZ!C&__\Q_^CAQO__BSCH6L+__[D"````,=)(B=Y(B<?H*,?__^ND,?_HO\;_
M_XLXZ#C"__^Y`@```#'23(GF2(G'Z`;'___I8?___V8/'X0``````$B#[`@Q
M_^B-QO__BSCH!L+__[G:7D``N@@@0`"^Y%Y``$B)QTB#Q`CI2\;__P\?`$B#
M[`@Q_^A=QO__BSCHUL'__TB)Q^BV____,?_H1\;__XLXZ,#!__]!N-1>0`!%
M,<FZD%=``$R)P;X`7T``2(G'2(/$".D>Q/__D)"0D)"02(T%$0$``$B%P'0,
M2(L-!0$``.E@PO__,<GK]Y"0D)#SPV9F9F9F+@\?A```````2(EL)-A,B60D
MX$B-+5ME(`!,C25492``3(EL).A,B70D\$R)?"3X2(E<)-!(@^PX3"GE08G]
M28GV2,']`TF)U^C[P/__2(7M=!PQVP\?0`!,B?I,B?9$B>]!_Q3<2(/#`4@Y
MZW+J2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,.0D)"0D)"0
M54B)Y5-(@^P(2(L%T&0@`$B#^/]T&;NPP6``#Q]$``!(@^L(_]!(BP-(@_C_
M=?%(@\0(6\G#D)!(@^P(Z-_%__](@\0(PP`````````````!``(`````````
M````````4$%27T-,14%.`"]P<F]C+W-E;&8O97AE`"XN`"5S+R5S`"]P<F]C
M+R5I+R5S`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]414U0`%!!4E]$14)51P!005)?0T%#2$4`4$%27U!23T=.04U%
M`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/
M0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/
M0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P87(M`"UE`"TM`$,Z7%1%35``+W1M
M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"5S)7,E<R5S`'!A<FP`+G!A
M<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P!365-414T`05)'5@`8`'!E<FP`<&5R;'AS:2YC`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O`#H`
M`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````
M```57T```````!=?0```````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@
M+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W
M:71H("5I+@H``````````````````````,!#<&%R+G!L````````````````
M````````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI
M<R!S8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@
M=&EM92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@
M(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R
M7W1E;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES
M(&-A=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E
M('1R>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R
M;VYG('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*
M("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T
M(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE
M<R!A;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET
M:"!A(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE
M(&9I;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*
M("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S
M92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E
M(&]F(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A8
M6%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@
M("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q
M"B`@('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@
M('-Y<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R
M;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@
M("`@+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF
M("AE>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P
M?2`I('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q
M("XN("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%2
M1U9?,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@
M(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@
M:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE
M*"D["E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG
M(&%N9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R
M=%]P;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@
M;V8@9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*
M("`@('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@
M("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E
M:R!?1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E
M:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"B`@("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M
M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B
M=68@97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@
M("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@
M("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP
M86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L
M("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O
M=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@
M("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@
M("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W
M-34L("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I
M;&4H*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-
M4'TO)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@
M)&9I;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T
M*3L*("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C
M;&]S92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@
M("`@("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D
M8W)C+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@
M("`@("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@
M("`@("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D
M7SL@;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@
M;W(@<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O
M)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@
M("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F
M:"`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@
M,"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F
M:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@
M*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@
M("`@("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@
M("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@
M("`@("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@
M8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C
M($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA
M;&EZ92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,
M;V%D97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A
M<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T
M)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@
M(')E<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R
M;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE
M<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL
M96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE
M+G!L(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@
M("`@?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@
M)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*
M;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C
M:&5?;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W
M(&%R9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M
M+7!A<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@
M)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD
M(#T@<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN
M<W1A;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S
M("`@<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@
M("`C(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO
M<'1I;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E
M('1H92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O
M9B!A;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I
M;&P@<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#
M*0H@("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M("`@("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@
M<&%R;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@
M("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@
M("!I9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?
M=&]?:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*
M("`@("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@
M("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L
M92`]("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H
M)#$@97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@
M>PH@("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@
M("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@
M)#(["B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*
M"B`@("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@
M("`@("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@
M("`@("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER
M92!005(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E
M>&ET.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP
M87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@
M:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@
M07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'
M5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@
M("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F
M:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@
M("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@
M("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@
M("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@
M("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O
M7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C
M($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O
M(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@
M4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN
M;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL
M92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#
M<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T
M85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO
M861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@
M(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@
M("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@
M("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D
M=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@
M("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*
M("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@
M("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO
M861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E
M(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@
M("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@
M("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@
M>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@
M("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G
M<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@
M("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N
M9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@
M=&5S="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL
M(&YO;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A
M=R]:;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD
M+6%I9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@
M("`@("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@
M;V8@=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@
M22!F86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@
M("`@+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@
M:V5Y<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.
M0SL*"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D
M9FEL92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M("`@("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@
M*"0Q+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>
M+UTK+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM
M>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I
M<B\D,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@
M(&QA<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I
M;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@
M("`@(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@
M("`@("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@
M("`@("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@
M("!I9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/2`D9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M92!["B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@
M9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,
M13X["B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@
M("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@
M("`@("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A
M=71O+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E
M;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*
M("`@("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A
M9&5R+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H
M5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I
M;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@
M("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T
M('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I
M9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I
M;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@
M("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U
M="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I
M*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S
M92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@
M("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP
M<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D
M(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@
M4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@
M("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?
M<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@
M<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("![
M"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0[
M"B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE
M("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@
M("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R
M<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL
M94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]
M?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI
M8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@
M("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE
M;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O
M=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A
M9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L
M<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M
M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@
M("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@
M?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@
M<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A
M=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E
M($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E
M('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A
M<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P[
M"B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P
M96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<[
M"B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE
M.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@
M("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@
M("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@
M("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L
M87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S
M(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I
M;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E
M=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T
M96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@
M;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U0
M1$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@
M("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@
M(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@
M("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]
M"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@
M("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.
M?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@
M("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@
M("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@
M)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#
M04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@
M("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@
M("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@
M("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K
M87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@
M("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C
M='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@
M("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@
M("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S
M=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@
M)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I
M;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@
M)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*
M("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE
M;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L
M("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*
M("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI
M=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?
M<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@
M)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*
M("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@
M("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@
M("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@
M("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O
M9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@
M("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@
M("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN
M,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U
M<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@
M("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=0
M05)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@
M(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'
M3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P
M87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T
M.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<
M;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@
M("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@
M('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C
M:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G
M;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*
M`````1L#.^@````<````I&?__P0!``#D9___'`$``%1^__],`0``1'___W0!
M``!D?___C`$``+1___^L`0``!(#__]P!```$@?__!`(``$2!__\<`@``)(/_
M_SP"``"TA/__G`(``%2%___$`@``1(;__^P"``!4AO__!`,``(2(__\T`P``
MQ(G__X0#``"4B___I`,``,2+__^\`P``U(S___0#``!4C?__+`0``(2/__]4
M!```A)'__Z0$``"DF___]`0``*2?__\T!0``U)___TP%```DH/__9`4``$2@
M__]\!0``5*#__Y0%```4``````````%Z4@`!>!`!&PP'")`!```4````'```
M`)AF__\T```````````````L````-````,!F__]K%@```$$.$$<.&$<.J`0"
MEH,#A@(#PQ4.&$$.$$$."``````D````9`````!]___D`````$V/`HP%6PY`
M18X#C02&!H,'9`H."$<+%````(P```#(??__%0````!$#B!0#@@`'````*0`
M``#0??__3`````!$#A!/"@X(10MJ"@X(1@LL````Q`````!^__])`````$$.
M$$.&`D$.&$0.,$6#`W@.&$$.$$$."``````````D````]````"!^___[````
M`$V-`H8$40[`(&.,`X,%`HL*#@A$"P``%````!P!``#X?O__0`````!$#A!W
M#@@`'````#0!```@?___V0$```!!#A!"@P(#U0$."`````!<````5`$``."`
M__^-`0```$(.$$(.&$(.($$.*$.&!8P$C0..`D$.,$<.P`%%@P9,"@XP00XH
M00X@0@X80@X00@X(10L"[PH.,$$.*$$.($(.&$(.$$(."$D+```````D````
MM`$``!""__^9`````$$.$$.#`FT*#@A'"P)@#@@`````````)````-P!``"(
M@O__X0````!6#L!`2(P"A@.#!`)U"@X(10L``````!0````$`@``4(/__P4`
M`````````````"P````<`@``2(/__R<"````68T$C`6&!H,'3@Y03X\"C@,"
M<`H."$H+`````````$P```!,`@``2(7__S8!````0@X00@X80@X@0XT$C@./
M`D(.*$:,!4$.,$$..$6#!X8&1`Z0`0*6"@XX00XP00XH0@X@0@X80@X00@X(
M1`L`'````)P"```XAO__RP$```!$#D`#;`$*#@A("P`````4````O`(``.B'
M__\B`````$0.$%T."``T````U`(```"(__\*`0```$0.$$.#`@)/"@X(2@M5
M"@X(2PL"5@H."$H+70H."$$+`````````#0````,`P``V(C__W\`````00X0
M0X8"00X81`X@@P,"90H.&$$.$$$."$$+1`X81`X000X(````)````$0#```@
MB?__*P(```!!#A!$#C!=@P(#A0$*#A!!#@A("P```$P```!L`P``*(O___X!
M````0@X00@X80@X@0XT$C@./`D(.*$.,!48.,$$..$<.\"!3@P>&!@)/"@XX
M00XP00XH0@X@0@X80@X00@X(00L`3````+P#``#8C/__%PH```!"#A!"#AA"
M#B!"#BA!#C!!#CA#@P>&!HP%C02.`X\"3`[0@P(#+@,*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A'"P`\````#`0``*B6___W`P```$(.$$0.&$$.($$.*$0.,(,%
MA@2,`XT"`UX""@XH00X@00X80@X00@X(2`L`````%````$P$``!HFO__+0``
M``!$#A!D#@@`%````&0$``"`FO__2@````!$#A`"00X(%````'P$``"XFO__
M'```````````````%````)0$``#`FO__`@``````````````)````*P$``"X
MFO__B0````!1C`6&!E\.0$:#!X\"C@.-!`)2#@@`````````````________
M__\``````````/__________``````````````````````$``````````0``
M```````!`````````*T"`````````0````````"\`@````````$`````````
MR`(````````!`````````-,"`````````0````````#=`@````````$`````
M````ZP(````````!`````````/@"`````````0````````!'`P````````\`
M````````G@0````````,`````````(`=0```````#0`````````(74``````
M`/7^_V\`````8`)````````%`````````#`.0```````!@````````!H`T``
M``````H`````````.`8````````+`````````!@`````````%0``````````
M``````````,``````````,1@```````"`````````&@'````````%```````
M```'`````````!<`````````&!9````````'`````````-`50```````"```
M``````!(``````````D`````````&`````````#^__]O`````%`50```````
M____;P`````"`````````/#__V\`````:!1`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`-C!8````````````````````````````*X=0```````OAU```````#.'4``
M`````-X=0```````[AU```````#^'4````````X>0```````'AY````````N
M'D```````#X>0```````3AY```````!>'D```````&X>0```````?AY`````
M``".'D```````)X>0```````KAY```````"^'D```````,X>0```````WAY`
M``````#N'D```````/X>0```````#A]````````>'T```````"X?0```````
M/A]```````!.'T```````%X?0```````;A]```````!^'T```````(X?0```
M````GA]```````"N'T```````+X?0```````SA]```````#>'T```````.X?
M0```````_A]````````.($```````!X@0```````+B!````````^($``````
M`$X@0```````7B!```````!N($```````'X@0```````CB!```````">($``
M`````*X@0```````OB!```````#.($```````-X@0```````[B!```````#^
M($````````XA0```````'B%````````N(4```````#XA0```````3B%`````
M``!>(4```````&XA0```````?B%```````".(4```````)XA0```````KB%`
M``````"^(4```````,XA0```````WB%```````#N(4```````/XA0```````
M#B)````````>(D```````"XB0```````/B)```````!.(D```````%XB0```
M````;B)```````!^(D```````(XB0````````````/_____H7T```````.E;
M````````1T-#.B`H1TY5*2`T+C0N-"`R,#$P,#4P,R`H4F5D($AA="`T+C0N
M-"TR*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG
M;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E
M<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD
M871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@```````````D`````````"````````'```````````````````
M``$````````````````````3````!P````(`````````'`)````````<`@``
M`````"`````````````````````$````````````````````(0````<````"
M`````````#P"0```````/`(````````D````````````````````!```````
M`````````````#0```#V__]O`@````````!@`D```````&`"````````!`$`
M```````%``````````@````````````````````^````"P````(`````````
M:`-```````!H`P```````,@*````````!@````$````(`````````!@`````
M````1@````,````"`````````#`.0```````,`X````````X!@``````````
M`````````0```````````````````$X```#___]O`@````````!H%$``````
M`&@4````````Y@`````````%``````````(``````````@````````!;````
M_O__;P(`````````4!5```````!0%0```````(``````````!@````(````(
M````````````````````:@````0````"`````````-`50```````T!4`````
M``!(``````````4`````````"``````````8`````````'0````$`````@``
M```````8%D```````!@6````````:`<````````%````#`````@`````````
M&`````````!^`````0````8`````````@!U```````"`'0```````!@`````
M```````````````$````````````````````>0````$````&`````````)@=
M0```````F!T`````````!0``````````````````!``````````0````````
M`(0````!````!@````````"@(D```````*`B````````:#H`````````````
M`````!````````````````````"*`````0````8`````````"%U````````(
M70````````X````````````````````$````````````````````D`````$`
M```"`````````"!=0```````(%T```````#*7@``````````````````(```
M`````````````````)@````!`````@````````#LNT```````.R[````````
M[`````````````````````0```````````````````"F`````0````(`````
M````V+Q```````#8O````````-0$```````````````````(````````````
M````````L`````$````#`````````+#!8```````L,$````````0````````
M````````````"````````````````````+<````!`````P````````#`P6``
M`````,#!````````$`````````````````````@```````````````````"^
M`````0````,`````````T,%@``````#0P0````````@`````````````````
M```(````````````````````PP````8````#`````````-C!8```````V,$`
M```````@`@````````8`````````"``````````0`````````,P````!````
M`P````````#XPV```````/C#````````"`````````````````````@`````
M````"`````````#1`````0````,``````````,1@````````Q````````)`"
M```````````````````(``````````@`````````V@````$````#````````
M`)#&8```````D,8````````8````````````````````"```````````````
M`````.`````(`````P````````#`QF```````*C&````````@!``````````
M`````````"````````````````````#E`````0```#``````````````````
M``"HQ@```````"P````````````````````!``````````$``````````0``
M``,`````````````````````````U,8```````#N````````````````````
0`0``````````````````````
